@@ -1,4 +1,7 @@
-use std::sync::Arc;
+use std::{
+    path::{Path, PathBuf},
+    sync::Arc,
+};
 
 use anyhow::{bail, Context, Result};
 use swc_common::{errors::HANDLER, Mark, SourceFile, SourceMap};
@@ -76,3 +79,22 @@ pub struct ModuleRecord {
     pub top_level_mark: Mark,
     pub unresolved_mark: Mark,
 }
+
+pub fn all_js_files(path: &Path) -> Result<Vec<PathBuf>> {
+    wrap_task(|| {
+        if path.is_dir() {
+            let mut files = vec![];
+            for entry in path.read_dir().context("failed to read dir")? {
+                let entry = entry.context("read_dir returned an error")?;
+                let path = entry.path();
+                files.extend(all_js_files(&path)?);
+            }
+            Ok(files)
+        } else if path.extension() == Some("js".as_ref()) {
+            Ok(vec![path.to_path_buf()])
+        } else {
+            Ok(vec![])
+        }
+    })
+    .with_context(|| format!("failed to get list of `.js` files in {}", path.display()))
+}
